measuretools.report_time_signature_distribution
===============================================

.. autofunction:: abjad.tools.measuretools.report_time_signature_distribution.report_time_signature_distribution
   :noindex:
